@@ -43,7 +43,7 @@ struct KIPIExportActionPrivate
 
     void updateMenu()
     {
-        QMenu* menu = static_cast<QMenu*>(q->menu());
+        auto* menu = static_cast<QMenu*>(q->menu());
         menu->clear();
 
         if (mDefaultAction && mExportActionList.contains(mDefaultAction)) {
@@ -63,7 +63,7 @@ struct KIPIExportActionPrivate
 };
 
 KIPIExportAction::KIPIExportAction(QObject* parent)
-: KToolBarPopupAction(QIcon::fromTheme("document-share"), i18nc("@action", "Share"), parent)
+: KToolBarPopupAction(QIcon::fromTheme(QStringLiteral("document-share")), i18nc("@action", "Share"), parent)
 , d(new KIPIExportActionPrivate)
 {
     d->q = this;
