@@ -36,7 +36,7 @@ class QUrl;
 namespace Gwenview
 {
 
-typedef QString SemanticInfoTag;
+using SemanticInfoTag = QString;
 
 /**
  * This class represents the set of tags associated to an url.
@@ -54,10 +54,8 @@ public:
     static TagSet fromVariant(const QVariant&);
     static TagSet fromList(const QList<SemanticInfoTag>&);
 
-#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
 private:
     TagSet(const QList<SemanticInfoTag>&);
-#endif
 };
 
 /**
